"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cheerio_1 = __importDefault(require("cheerio"));
const color_1 = __importDefault(require("color"));
const through2_1 = __importDefault(require("through2"));
/**
 * Returns a transform stream that the SVG data can be
 * piped into. It will output the filled SVG data.
 *
 * @param svgFill   The SvgFill instance that will recolour
 *                   the streamed SVG data.
 */
function makeStream(svgFill) {
    let svgData = Buffer.alloc(0);
    return (0, through2_1.default)(function (chunk, enc, cb) {
        // accumulate data
        svgData = Buffer.concat([svgData, chunk]);
        cb();
    }, function (cb) {
        // Now fill the SVG and push the result
        this.push(svgFill.fillSvg(svgData));
        cb();
    });
}
class SvgFill {
    constructor(fillColor) {
        this.setFillColor(fillColor);
    }
    setFillColor(fillColor) {
        this._fillColor = fillColor instanceof color_1.default ? fillColor : new color_1.default(fillColor);
    }
    getFillColor() {
        return this._fillColor;
    }
    /**
     * Fills all shapes in the SVG with the fill color.
     *
     * Note, this is currently a naive solution that simply adds a fill
     * attribute with the chosen fill color to the SVG element. For SVGs
     * without styling attributes, such as ones to be composed into
     * a symbol sprite, this should work fine. For anything else, the
     * results will be hit and miss.
     *
     * @param svgData A string or buffer containing valid SVG data.
     */
    fillSvg(svgData) {
        // Forcing svgData to be "string" for TypeScript's benefit.
        // In actual fact, cheerio.load() does accept Buffers too.
        const $ = cheerio_1.default.load(svgData, { xmlMode: true });
        $('svg').attr('fill', this.getFillColor().hex());
        return $.xml();
    }
    /**
     * Returns a transform stream that the SVG data can be
     * piped into. It will output the filled SVG data.
     *
     * Note: This function is primarily for developer convenience.
     * Internally, it waits until the entire SVG data has been received,
     * before doing the transform and outputting it. Therefore, you
     * don't really reap the benefits of streams, as any consumer will be
     * stuck waiting until the full SVG data has been buffered and
     * transformed.
     */
    fillSvgStream() {
        return makeStream(this);
    }
}
exports.default = SvgFill;
//# sourceMappingURL=index.js.map